searchData={"items":[{"type":"module","title":"Peri","doc":"Peri is a schema validation library for Elixir, inspired by Clojure's Plumatic Schema.\nIt focuses on validating raw maps and supports nested schemas and optional fields.","ref":"Peri.html"},{"type":"module","title":"Usage - Peri","doc":"To define a schema, use the `defschema` macro. By default, all fields in the schema are optional unless specified as `{:required, type}`.\n\n```elixir\ndefmodule MySchemas do\n  import Peri\n\n  defschema :user, %{\n    name: :string,\n    age: :integer,\n    email: {:required, :string},\n    address: %{\n      street: :string,\n      city: :string\n    },\n    tags: {:list, :string},\n    role: {:enum, [:admin, :user, :guest]},\n    geolocation: {:tuple, [:float, :float]},\n    rating: {:custom, &validate_rating/1}\n  }\n\n  defp validate_rating(n) when n < 10, do: :ok\n  defp validate_rating(_), do: {:error, \"invalid rating\"}\nend\n```\n\nYou can then use the schema to validate data:\n\n```elixir\nuser_data = %{name: \"John\", age: 30, email: \"john@example.com\", address: %{street: \"123 Main St\", city: \"Somewhere\"}, tags: [\"science\", \"funky\"], role: :admin, geolocation: {12.2, 34.2}, rating: 9}\ncase MySchemas.user(user_data) do\n  {:ok, valid_data} -> IO.puts(\"Data is valid!\")\n  {:error, errors} -> IO.inspect(errors, label: \"Validation errors\")\nend\n```","ref":"Peri.html#module-usage"},{"type":"module","title":"Available Types - Peri","doc":"- `:string` - Validates that the field is a binary (string).\n- `:integer` - Validates that the field is an integer.\n- `:float` - Validates that the field is a float.\n- `:boolean` - Validates that the field is a boolean.\n- `{:required, type}` - Marks the field as required and validates it according to the specified type.\n- `:map` - Validates that the field is a map without checking nested schema.\n- `{:list, type}` - Validates that the field is a list where elements belongs to a determined type.\n- `{:tuple, types}` - Validates that the field is a tuple with determined size and each element have your own type validation (sequential).\n- `{custom, anonymous_fun_arity_1}` - Validates that the field passes on the callback, the function needs to return either `:ok` or `{:error, reason}` where `reason` should be a string.\n- `{:custom, {MyModule, :my_validation}}` - Same as `{custom, anonymous_fun_arity_1}` but you pass a remote module and a function name as atom.\n- `{:custom, {MyModule, :my_validation, [arg1, arg2]}}` - Same as `{:custom, {MyModule, :my_validation}}` but you can pass extra arguments to your validation function. Note that the value of the field is always the first argument.","ref":"Peri.html#module-available-types"},{"type":"macro","title":"Peri.defschema/2","doc":"Defines a schema with a given name and schema definition.","ref":"Peri.html#defschema/2"},{"type":"macro","title":"Examples - Peri.defschema/2","doc":"defmodule MySchemas do\n      import Peri\n\n      defschema :user, %{\n        name: :string,\n        age: :integer,\n        email: {:required, :string}\n      }\n    end\n\n    user_data = %{name: \"John\", age: 30, email: \"john@example.com\"}\n    MySchemas.user(user_data)\n    # => {:ok, %{name: \"John\", age: 30, email: \"john@example.com\"}}\n\n    invalid_data = %{name: \"John\", age: 30}\n    MySchemas.user(invalid_data)\n    # => {:error, [email: \"is required\"]}","ref":"Peri.html#defschema/2-examples"},{"type":"function","title":"Peri.validate/2","doc":"Validates a given data map against a schema.\n\nReturns `{:ok, data}` if the data is valid according to the schema, or `{:error, errors}` if there are validation errors.","ref":"Peri.html#validate/2"},{"type":"function","title":"Parameters - Peri.validate/2","doc":"- schema: The schema definition map.\n  - data: The data map to be validated.","ref":"Peri.html#validate/2-parameters"},{"type":"function","title":"Examples - Peri.validate/2","doc":"schema = %{\n      name: :string,\n      age: :integer,\n      email: {:required, :string}\n    }\n\n    data = %{name: \"John\", age: 30, email: \"john@example.com\"}\n    Peri.validate(schema, data)\n    # => {:ok, %{name: \"John\", age: 30, email: \"john@example.com\"}}\n\n    invalid_data = %{name: \"John\", age: 30}\n    Peri.validate(schema, invalid_data)\n    # => {:error, [email: \"is required\"]}","ref":"Peri.html#validate/2-examples"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}